@@ -42,34 +42,43 @@ namespace Mono.Addins.Gui
 		ListStore treeStore;
 		SetupService service;
 		
-		public ManageSitesDialog (SetupService service)
+		public ManageSitesDialog (Gtk.Window parent, SetupService service)
 		{
 			Build ();
+			TransientFor = parent;
+			Services.PlaceDialog (this, parent);
 			this.service = service;
-			treeStore = new Gtk.ListStore (typeof (string), typeof (string));
+			treeStore = new Gtk.ListStore (typeof (string), typeof (string), typeof(bool));
 			repoTree.Model = treeStore;
-			repoTree.HeadersVisible = true;
-			repoTree.AppendColumn (Catalog.GetString ("Name"), new Gtk.CellRendererText (), "text", 1);
-			repoTree.AppendColumn (Catalog.GetString ("Url"), new Gtk.CellRendererText (), "text", 0);
+			repoTree.HeadersVisible = false;
+			var crt = new Gtk.CellRendererToggle ();
+			crt.Toggled += HandleRepoToggled;
+			repoTree.AppendColumn ("", crt, "active", 2);
+			repoTree.AppendColumn ("", new Gtk.CellRendererText (), "markup", 1);
 			repoTree.Selection.Changed += new EventHandler(OnSelect);
 			
 			AddinRepository[] reps = service.Repositories.GetRepositories ();
-			foreach (AddinRepository rep in reps) {
-				treeStore.AppendValues (rep.Url, rep.Title);
-			}
+			foreach (AddinRepository rep in reps)
+				AppendRepository (rep);
 
 			btnRemove.Sensitive = false;
 		}
-		
+
 		public override void Dispose ()
 		{
 			base.Dispose ();
 			Destroy ();
 		}
 		
+		void AppendRepository (AddinRepository rep)
+		{
+			string txt = GLib.Markup.EscapeText (rep.Title) + "\n<span color='darkgray'>" + GLib.Markup.EscapeText (rep.Url) + "</span>";
+			treeStore.AppendValues (rep.Url, txt, rep.Enabled);
+		}
+		
 		protected void OnAdd (object sender, EventArgs e)
 		{
-			NewSiteDialog dlg = new NewSiteDialog ();
+			NewSiteDialog dlg = new NewSiteDialog (this);
 			try {
 				if (dlg.Run ()) {
 					string url = dlg.Url;
@@ -84,7 +93,7 @@ namespace Mono.Addins.Gui
 					}
 					
 					if (!service.Repositories.ContainsRepository (url)) {
-						ProgressDialog pdlg = new ProgressDialog ();
+						ProgressDialog pdlg = new ProgressDialog (this);
 						pdlg.Show ();
 						pdlg.SetMessage (AddinManager.CurrentLocalizer.GetString ("Registering repository"));
 						
@@ -122,7 +131,7 @@ namespace Mono.Addins.Gui
 							return;
 						}
 						
-						treeStore.AppendValues (rr.Url, rr.Title);
+						AppendRepository (rr);
 					}
 				}
 			} finally {
@@ -143,6 +152,19 @@ namespace Mono.Addins.Gui
 			treeStore.Remove (ref iter);
 		}
 
+		void HandleRepoToggled (object o, ToggledArgs args)
+		{
+			Gtk.TreeIter iter;
+			if (!treeStore.GetIterFromString (out iter, args.Path))
+				return;
+			
+			bool newVal = !(bool) treeStore.GetValue (iter, 2);
+			string rep = (string) treeStore.GetValue (iter, 0);
+			service.Repositories.SetRepositoryEnabled (rep, newVal);
+			
+			treeStore.SetValue (iter, 2, newVal);
+		}
+		
 		protected void OnSelect(object sender, EventArgs e)
 		{
 			btnRemove.Sensitive = repoTree.Selection.CountSelectedRows() > 0;
